import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { ComputeType } from '@project-lakechain/core/compute-type';
import { CacheStorage } from '@project-lakechain/core';
import { SharpOperations } from './definitions';
import { SharpImageTransformProps } from './definitions/opts';
import { Middleware, MiddlewareBuilder } from '@project-lakechain/core/middleware';
/**
 * Builder for the `SharpImageTransform` middleware.
 */
declare class SharpImageTransformBuilder extends MiddlewareBuilder {
    private providerProps;
    /**
     * @param sharpTransforms the sharp transforms to apply.
     */
    withSharpTransforms(sharpTransforms: SharpOperations): this;
    /**
     * @returns a new instance of the `SharpImageTransform`
     * service constructed with the given parameters.
     */
    build(): SharpImageTransform;
}
/**
 * A middleware allowing to transform images using the
 * sharp library.
 */
export declare class SharpImageTransform extends Middleware {
    private props;
    /**
     * The storage containing processed files.
     */
    storage: CacheStorage;
    /**
     * The event processing lambda function.
     */
    eventProcessor: lambda.IFunction;
    /**
     * The builder for the `SharpImageTransform` service.
     */
    static Builder: typeof SharpImageTransformBuilder;
    /**
     * Provider constructor.
     */
    constructor(scope: Construct, id: string, props: SharpImageTransformProps);
    /**
     * Allows a grantee to read from the processed documents
     * generated by this middleware.
     */
    grantReadProcessedDocuments(grantee: iam.IGrantable): iam.Grant;
    /**
     * @returns an array of mime-types supported as input
     * type by the data producer.
     */
    supportedInputTypes(): string[];
    /**
     * @returns an array of mime-types supported as output
     * type by the data producer.
     */
    supportedOutputTypes(): string[];
    /**
     * @returns the supported compute types by a given
     * middleware.
     */
    supportedComputeTypes(): ComputeType[];
    /**
     * @returns the middleware conditional statement defining
     * in which conditions this middleware should be executed.
     * In this case, we want the middleware to only be invoked
     * when the document mime-type is supported, and the event
     * type is `document-created`.
     */
    conditional(): import("@project-lakechain/core").ConditionalStatement;
}
export { sharp } from './definitions/index';
